==> camel-kafka-connector-0.7.1-src.zip: apache-camel-kafkaconnector-0.7.1/tests/itests-ssh/src/test/java/org/apache/camel/kafkaconnector/ssh/services/SshLocalContainerService.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.apache.camel.kafkaconnector.ssh.services;

import org.slf4j.Logger;
import org.slf4j.LoggerFactory;

public class SshLocalContainerService implements SshService {
    private static final Logger LOG = LoggerFactory.getLogger(SshLocalContainerService.class);

    private SshContainer container;

    public SshLocalContainerService() {
        container = new SshContainer();

        container.start();
    }

    @Override
    public int getSshPort() {
        return container.getSSHPort();
    }

    @Override
    public String getSshHost() {
        return container.getSSHHost();
    }

    @Override
    public void initialize() {
        LOG.info("SSH server running at address {}", getSshEndpoint());
    }

    @Override
    public void shutdown() {
        LOG.info("Stopping the Ssh container");
        container.stop();
    }
}

==> camel-kafka-connector-4.14.0-src.zip: apache-camel-kafkaconnector-4.14.0/tests/itests-ssh/src/test/java/org/apache/camel/kafkaconnector/ssh/services/SshLocalContainerService.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.apache.camel.kafkaconnector.ssh.services;

import org.apache.camel.kafkaconnector.ssh.common.SshProperties;
import org.apache.camel.test.infra.common.services.ContainerService;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;

public class SshLocalContainerService implements SshService, ContainerService<SshContainer> {
    private static final Logger LOG = LoggerFactory.getLogger(SshLocalContainerService.class);

    private SshContainer container;

    public SshLocalContainerService() {
        container = new SshContainer();
    }

    @Override
    public int getSshPort() {
        return container.getSSHPort();
    }

    @Override
    public String getSshHost() {
        return container.getSSHHost();
    }

    @Override
    public void registerProperties() {
        System.setProperty(SshProperties.SSH_PORT, String.valueOf(getSshPort()));
        System.setProperty(SshProperties.SSH_HOST, getSshHost());
    }

    @Override
    public void initialize() {
        container.start();
        LOG.info("SSH server running at address {}", getSshEndpoint());
    }

    @Override
    public void shutdown() {
        LOG.info("Stopping the Ssh container");
        container.stop();
    }

    @Override
    public SshContainer getContainer() {
        return container;
    }
}
